@@ -1,4 +1,3 @@
-context("Data")
 ds <- Data$new(iris)
 sample1 <- ds$sample(3)
 n <- 100
@@ -39,3 +38,10 @@ test_that("y as character works", {
   expect_equal(ds$feature.names, setdiff(colnames(iris), "Species"))
   expect_equal(unname(ds$feature.types), rep("numerical", times = 4))
 })
+
+
+test_that("only first class used", {
+  data("diamonds")
+  x = Data$new(X = diamonds)
+  expect_true(!any(is.na(names(x$feature.types))))
+})
